// ============================================================================
// Copyright (c) 2016 by Terasic Technologies Inc.
// ============================================================================
//
// Permission:
//
//   Terasic grants permission to use and modify this code for use
//   in synthesis for all Terasic Development Boards and Altera Development 
//   Kits made by Terasic.  Other use of this code, including the selling 
//   ,duplication, or modification of any portion is strictly prohibited.
//
// Disclaimer:
//
//   This VHDL/Verilog or C/C++ source code is intended as a design reference
//   which illustrates how these types of functions can be implemented.
//   It is the user's responsibility to verify their design for
//   consistency and functionality through the use of formal
//   verification methods.  Terasic provides no warranty regarding the use 
//   or functionality of this code.
//
// ============================================================================
//           
//  Terasic Technologies Inc
//  9F., No.176, Sec.2, Gongdao 5th Rd, East Dist, Hsinchu City, 30070. Taiwan
//  
//  
//                     web: http://www.terasic.com/  
//                     email: support@terasic.com
//
// ============================================================================
//Date:  Tue Jul  5 10:47:02 2016
// ============================================================================

//`define ENABLE_HPS

module ADC_SoC_HIGH_SPEED_ADC(

      ///////// CLOCK /////////
      input              FPGA_CLK1_50,
      input              FPGA_CLK2_50,
      input              FPGA_CLK3_50,

      ///////// KEY /////////
      input    [ 1: 0]   KEY, //KEY is Low-Active

      ///////// SW /////////
      input    [ 3: 0]   SW,

      ///////// LED /////////
      output   [ 7: 0]   LED,

      ///////// HDMI /////////
      inout              HDMI_I2C_SCL,
      inout              HDMI_I2C_SDA,

      ///////// ADC /////////
      output             ADC_SCK,
      input              ADC_SDO,
      output             ADC_SDI,
      output             ADC_CONVST,

      ///////// GPIO /////////
      inout    [35: 0]   GPIO_1,

      ///////// ARDUINO /////////
      inout    [15: 0]   ARDUINO_IO,
      inout              ARDUINO_RESET_N,



`ifdef ENABLE_HPS
      ///////// HPS /////////
      inout              HPS_CONV_USB_N,
      output   [14: 0]   HPS_DDR3_ADDR,
      output   [ 2: 0]   HPS_DDR3_BA,
      output             HPS_DDR3_CAS_N,
      output             HPS_DDR3_CKE,
      output             HPS_DDR3_CK_N,
      output             HPS_DDR3_CK_P,
      output             HPS_DDR3_CS_N,
      output   [ 3: 0]   HPS_DDR3_DM,
      inout    [31: 0]   HPS_DDR3_DQ,
      inout    [ 3: 0]   HPS_DDR3_DQS_N,
      inout    [ 3: 0]   HPS_DDR3_DQS_P,
      output             HPS_DDR3_ODT,
      output             HPS_DDR3_RAS_N,
      output             HPS_DDR3_RESET_N,
      input              HPS_DDR3_RZQ,
      output             HPS_DDR3_WE_N,
      output             HPS_ENET_GTX_CLK,
      inout              HPS_ENET_INT_N,
      output             HPS_ENET_MDC,
      inout              HPS_ENET_MDIO,
      input              HPS_ENET_RX_CLK,
      input    [ 3: 0]   HPS_ENET_RX_DATA,
      input              HPS_ENET_RX_DV,
      output   [ 3: 0]   HPS_ENET_TX_DATA,
      output             HPS_ENET_TX_EN,
      inout              HPS_GSENSOR_INT,
      inout              HPS_I2C0_SCLK,
      inout              HPS_I2C0_SDAT,
      inout              HPS_I2C1_SCLK,
      inout              HPS_I2C1_SDAT,
      inout              HPS_KEY,
      inout              HPS_LED,
      inout              HPS_LTC_GPIO,
      output             HPS_SD_CLK,
      inout              HPS_SD_CMD,
      inout    [ 3: 0]   HPS_SD_DATA,
      output             HPS_SPIM_CLK,
      input              HPS_SPIM_MISO,
      output             HPS_SPIM_MOSI,
      inout              HPS_SPIM_SS,
      input              HPS_UART_RX,
      output             HPS_UART_TX,
      input              HPS_USB_CLKOUT,
      inout    [ 7: 0]   HPS_USB_DATA,
      input              HPS_USB_DIR,
      input              HPS_USB_NXT,
      output             HPS_USB_STP,
`endif /*ENABLE_HPS*/

      ///////// DCC /////////
      output             ADA_CLK_P,
      output             ADA_CLK_N,
      input    [13: 0]   ADA_D,
      input              ADA_DCO,
      output             ADA_OE,
      input              ADA_OR,

      output             ADB_CLK_P,
      output             ADB_CLK_N,
      input    [13: 0]   ADB_D,
      input              ADB_DCO,
      output             ADB_OE,
      input              ADB_OR,

      inout              AD_SCLK,
      inout              AD_SDIO,
      output             ADA_SPI_CS,
      output             ADB_SPI_CS

);


//=======================================================
//  REG/WIRE declarations
//=======================================================
wire						RESET_N;
wire						SYS_CLK;
wire				      PLL_LOCKED;
wire 			[13:0]	A2DA_DATA;
wire 		   [13:0]	A2DB_DATA;
wire                 HAVE_A;
wire                 HAVE_B;
wire                 TIME_OUT ; 
//=======================================================
//  Structural coding
//=======================================================

//--DEBUNCE
FTR disp(
   .CLK( SYS_CLK ), 
   .DI ( &KEY    )
); 

//--LED
assign	LED[0]			= HAVE_A; // ---- HAVE SIGNAL : 1 
assign	LED[1]			= HAVE_B; // ---- HAVE SIGNAL : 1 

//--RESET
assign	RESET_N			= &KEY;

//---assign for ADC control signal
assign	AD_SCLK			= 1;		         // (DFS)Data Format Select
assign	AD_SDIO			= 0;		       	// (DCS)Duty Cycle Stabilizer Select
assign	ADA_OE			= 1'b0;				// enable ADA output
assign	ADA_SPI_CS		= 1'b1;				// disable ADA_SPI_CS (CSB)
assign	ADB_OE			= 1'b0;				// enable ADB output
assign	ADB_SPI_CS		= 1'b1;				// disable ADB_SPI_CS (CSB)


//---ADC CLOCK ---
assign	ADA_CLK_P	=  SYS_CLK;
assign	ADA_CLK_N	= ~SYS_CLK;
assign	ADB_CLK_P	=  SYS_CLK;
assign	ADB_CLK_N	= ~SYS_CLK;

//---PLL  100MHZ 
PLL		pll_inst(
		.refclk   ( FPGA_CLK3_50), 
		.rst      ( ~RESET_N),     
		.outclk_0 ( SYS_CLK )

	);
		
//---analog to digital converter capture and sync Channel
TWO_CH_ADC_SYNC  tw( 
 .SYS_CLK  ( SYS_CLK ), 
 .RESET_N  ( RESET_N ),
 .ADA_DCO  ( ADA_DCO ),  //ADC-A input CLOCK
 .ADB_DCO  ( ADB_DCO ),  //ADC-B input CLOCK
 .ADA_D    ( ADA_D   ),  //ADC-A input DATA
 .ADB_D    ( ADB_D   ),  //ADC-B input DATA
 .A2DA_DATA( A2DA_DATA ),//Sync ADC-A DATA
 .A2DB_DATA( A2DB_DATA ) //Sync ADC-B DATA
 );

//---TO do Full wave rectifier / Detect Have Signal
ADC_RD_DET adr(
  .RESET_N ( RESET_N  ),
  .CLK_P   ( SYS_CLK  ), 
  .SADA_D  ( A2DA_DATA), //---- ADC-A  input
  .SADB_D  ( A2DB_DATA), //---- ADC-B  input
  .HAVE_A  ( HAVE_A   ), //---- HAVE SIGNAL =1
  .HAVE_B  ( HAVE_B   ), //---- HAVE SIGNAL =1
  .PD_A    (),           //-----Full wave rectifier from ADC-A
  .PD_B    ()            //-----Full wave rectifier from ADC-B
 );



endmodule
